---
title: <span class="badge object-type-scalar"></span> KiloNewtons
---
# <span class="badge object-type-scalar"></span> KiloNewtons

Force: Kilonewtons (kN)

## Definition

```python
# Force: Kilonewtons (kN)
KiloNewtons: typing.Literal["forcekN"] = "forcekN"
```
